@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,19 +20,25 @@
 #ifndef FST_ACCUMULATOR_H_
 #define FST_ACCUMULATOR_H_
 
+#include <sys/types.h>
+
 #include <algorithm>
+#include <cstddef>
 #include <functional>
 #include <memory>
+#include <utility>
 #include <vector>
 
 #include <fst/log.h>
-
 #include <fst/arcfilter.h>
 #include <fst/arcsort.h>
 #include <fst/dfs-visit.h>
 #include <fst/expanded-fst.h>
+#include <fst/float-weight.h>
+#include <fst/fst.h>
 #include <fst/replace.h>
-
+#include <fst/util.h>
+#include <fst/weight.h>
 #include <unordered_map>
 
 namespace fst {
@@ -46,7 +52,7 @@ class DefaultAccumulator {
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  DefaultAccumulator() {}
+  DefaultAccumulator() = default;
 
   DefaultAccumulator(const DefaultAccumulator &acc, bool safe = false) {}
 
@@ -81,7 +87,7 @@ class LogAccumulator {
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  LogAccumulator() {}
+  LogAccumulator() = default;
 
   LogAccumulator(const LogAccumulator &acc, bool safe = false) {}
 
@@ -135,7 +141,7 @@ class FastLogAccumulatorData {
         weight_positions_ptr_(nullptr),
         num_positions_(0) {}
 
-  virtual ~FastLogAccumulatorData() {}
+  virtual ~FastLogAccumulatorData() = default;
 
   // Cummulative weight per state for all states s.t. # of arcs > arc_limit_
   // with arcs in order. The first element per state is Log64Weight::Zero().
@@ -421,8 +427,7 @@ class CacheLogAccumulatorData {
   bool CacheDisabled() const { return cache_gc_ && cache_limit_ == 0; }
 
   std::vector<double> *GetWeights(StateId s) {
-    auto it = cache_.find(s);
-    if (it != cache_.end()) {
+    if (auto it = cache_.find(s); it != cache_.end()) {
       it->second.recent = true;
       return it->second.weights.get();
     } else {
@@ -430,10 +435,10 @@ class CacheLogAccumulatorData {
     }
   }
 
-  void AddWeights(StateId s, std::vector<double> *weights) {
+  void AddWeights(StateId s, std::unique_ptr<std::vector<double>> weights) {
     if (cache_gc_ && cache_size_ >= cache_limit_) GC(false);
-    cache_.emplace(s, CacheState(weights, true));
     if (cache_gc_) cache_size_ += weights->capacity() * sizeof(double);
+    cache_.emplace(s, CacheState(std::move(weights), true));
   }
 
  private:
@@ -442,8 +447,8 @@ class CacheLogAccumulatorData {
     std::unique_ptr<std::vector<double>> weights;  // Accumulated weights.
     bool recent;  // Has this state been accessed since last GC?
 
-    CacheState(std::vector<double> *weights, bool recent)
-        : weights(weights), recent(recent) {}
+    CacheState(std::unique_ptr<std::vector<double>> weights, bool recent)
+        : weights(std::move(weights)), recent(recent) {}
   };
 
   // Garbage collect: Deletes from cache states that have not been accessed
@@ -525,10 +530,13 @@ class CacheLogAccumulator {
     }
     weights_ = data_->GetWeights(s);
     if ((weights_ == nullptr) && (fst_->NumArcs(s) >= arc_limit_)) {
-      weights_ = new std::vector<double>;
-      weights_->reserve(fst_->NumArcs(s) + 1);
-      weights_->push_back(FloatLimits<double>::PosInfinity());
-      data_->AddWeights(s, weights_);
+      auto weights = std::make_unique<std::vector<double>>();
+      weights->reserve(fst_->NumArcs(s) + 1);
+      weights->push_back(FloatLimits<double>::PosInfinity());
+      // `weights` holds a reference to the weight vector, whose ownership is
+      // transferred to `data_`.
+      weights_ = weights.get();
+      data_->AddWeights(s, std::move(weights));
     }
   }
 
@@ -649,6 +657,7 @@ class CacheLogAccumulator {
   const WeightConvert<Log64Weight, Weight> to_weight_{};
   ssize_t arc_limit_;                    // Minimum # of arcs to cache a state.
   std::vector<double> *weights_;         // Accumulated weights for cur. state.
+                                         // Pointee owned by `data_`.
   std::unique_ptr<const Fst<Arc>> fst_;  // Input FST.
   std::shared_ptr<CacheLogAccumulatorData<Arc>> data_;  // Cache data.
   StateId s_;                                           // Current state.
@@ -773,7 +782,7 @@ class ReplaceAccumulator {
       offset_weight_ = Weight::Zero();
     }
     aiter_ = std::make_unique<ArcIterator<Fst<Arc>>>(*data_->GetFst(fst_id_),
-                                                      tuple.fst_state);
+                                                     tuple.fst_state);
   }
 
   Weight Sum(Weight w, Weight v) {
@@ -816,7 +825,7 @@ class SafeReplaceAccumulator {
   using StateTable = T;
   using StateTuple = typename StateTable::StateTuple;
 
-  SafeReplaceAccumulator() {}
+  SafeReplaceAccumulator() = default;
 
   SafeReplaceAccumulator(const SafeReplaceAccumulator &copy, bool safe)
       : SafeReplaceAccumulator(copy) {}
@@ -885,7 +894,7 @@ class SafeReplaceAccumulator {
  private:
   class ArcIteratorPtr {
    public:
-    ArcIteratorPtr() {}
+    ArcIteratorPtr() = default;
 
     ArcIteratorPtr(const ArcIteratorPtr &copy) {}
 
