@@ -134,17 +134,19 @@ class ComplementFstImpl : public FstImpl<A> {
 // reference counting, delegating most methods to ImplToFst.
 template <class A>
 class ComplementFst : public ImplToFst<internal::ComplementFstImpl<A>> {
+  using Base = ImplToFst<internal::ComplementFstImpl<A>>;
+
  public:
   using Arc = A;
   using Label = typename Arc::Label;
   using StateId = typename Arc::StateId;
-  using Impl = internal::ComplementFstImpl<Arc>;
+  using typename Base::Impl;
 
   friend class StateIterator<ComplementFst<Arc>>;
   friend class ArcIterator<ComplementFst<Arc>>;
 
   explicit ComplementFst(const Fst<Arc> &fst)
-      : ImplToFst<Impl>(std::make_shared<Impl>(fst)) {
+      : Base(std::make_shared<Impl>(fst)) {
     static constexpr auto props =
         kUnweighted | kNoEpsilons | kIDeterministic | kAcceptor;
     if (fst.Properties(props, true) != props) {
@@ -156,7 +158,7 @@ class ComplementFst : public ImplToFst<internal::ComplementFstImpl<A>> {
 
   // See Fst<>::Copy() for doc.
   ComplementFst(const ComplementFst &fst, bool safe = false)
-      : ImplToFst<Impl>(fst, safe) {}
+      : Base(fst, safe) {}
 
   // Gets a copy of this FST. See Fst<>::Copy() for further doc.
   ComplementFst *Copy(bool safe = false) const override {
@@ -173,7 +175,7 @@ class ComplementFst : public ImplToFst<internal::ComplementFstImpl<A>> {
   static constexpr Label kRhoLabel = -2;
 
  private:
-  using ImplToFst<Impl>::GetImpl;
+  using Base::GetImpl;
 
   ComplementFst &operator=(const ComplementFst &) = delete;
 };
