@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -41,12 +41,12 @@
 #define FST_EXPECTATION_WEIGHT_H_
 
 #include <cstdint>
+#include <random>
 #include <string>
 
 #include <fst/log.h>
-
 #include <fst/pair-weight.h>
-
+#include <fst/weight.h>
 
 namespace fst {
 
