@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -15,10 +15,13 @@
 #ifndef FST_EXTENSIONS_FAR_CONVERT_H_
 #define FST_EXTENSIONS_FAR_CONVERT_H_
 
+#include <fst/log.h>
 #include <fst/extensions/far/far.h>
 #include <fst/extensions/far/getters.h>
 #include <fst/extensions/far/map-reduce.h>
+#include <fst/fst.h>
 #include <fst/register.h>
+#include <fst/util.h>
 #include <string_view>
 
 namespace fst {
