@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,11 +20,24 @@
 #ifndef FST_EXTENSIONS_PDT_COMPOSE_H_
 #define FST_EXTENSIONS_PDT_COMPOSE_H_
 
+#include <sys/types.h>
+
 #include <cstdint>
 #include <list>
+#include <utility>
+#include <vector>
 
+#include <fst/log.h>
 #include <fst/extensions/pdt/pdt.h>
+#include <fst/compose-filter.h>
 #include <fst/compose.h>
+#include <fst/connect.h>
+#include <fst/filter-state.h>
+#include <fst/fst.h>
+#include <fst/matcher.h>
+#include <fst/mutable-fst.h>
+#include <fst/properties.h>
+#include <fst/util.h>
 
 namespace fst {
 
