@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -24,9 +24,13 @@
 #include <ostream>
 #include <string>
 
+#include <fst/log.h>
+#include <fst/arc.h>
 #include <fst/const-fst.h>
+#include <fst/fst.h>
 #include <fst/matcher-fst.h>
 #include <fst/matcher.h>
+#include <fst/util.h>
 
 DECLARE_int64(rho_fst_rho_label);
 DECLARE_string(rho_fst_rewrite_mode);
@@ -48,12 +52,12 @@ class RhoFstMatcherData {
 
   static RhoFstMatcherData<Label> *Read(std::istream &istrm,
                                         const FstReadOptions &read) {
-    auto *data = new RhoFstMatcherData<Label>();
+    auto data = std::make_unique<RhoFstMatcherData<Label>>();
     ReadType(istrm, &data->rho_label_);
     int32_t rewrite_mode;
     ReadType(istrm, &rewrite_mode);
     data->rewrite_mode_ = static_cast<MatcherRewriteMode>(rewrite_mode);
-    return data;
+    return data.release();
   }
 
   bool Write(std::ostream &ostrm, const FstWriteOptions &opts) const {
