@@ -460,6 +460,8 @@ class FactorWeightFstImpl : public CacheImpl<Arc> {
 template <class A, class FactorIterator>
 class FactorWeightFst
     : public ImplToFst<internal::FactorWeightFstImpl<A, FactorIterator>> {
+  using Base = ImplToFst<internal::FactorWeightFstImpl<A, FactorIterator>>;
+
  public:
   using Arc = A;
   using StateId = typename Arc::StateId;
@@ -467,21 +469,19 @@ class FactorWeightFst
 
   using Store = DefaultCacheStore<Arc>;
   using State = typename Store::State;
-  using Impl = internal::FactorWeightFstImpl<Arc, FactorIterator>;
+  using typename Base::Impl;
 
   friend class ArcIterator<FactorWeightFst<Arc, FactorIterator>>;
   friend class StateIterator<FactorWeightFst<Arc, FactorIterator>>;
 
   explicit FactorWeightFst(const Fst<Arc> &fst)
-      : ImplToFst<Impl>(
-            std::make_shared<Impl>(fst, FactorWeightOptions<Arc>())) {}
+      : Base(std::make_shared<Impl>(fst, FactorWeightOptions<Arc>())) {}
 
   FactorWeightFst(const Fst<Arc> &fst, const FactorWeightOptions<Arc> &opts)
-      : ImplToFst<Impl>(std::make_shared<Impl>(fst, opts)) {}
+      : Base(std::make_shared<Impl>(fst, opts)) {}
 
   // See Fst<>::Copy() for doc.
-  FactorWeightFst(const FactorWeightFst &fst, bool copy)
-      : ImplToFst<Impl>(fst, copy) {}
+  FactorWeightFst(const FactorWeightFst &fst, bool copy) : Base(fst, copy) {}
 
   // Get a copy of this FactorWeightFst. See Fst<>::Copy() for further doc.
   FactorWeightFst *Copy(bool copy = false) const override {
@@ -495,8 +495,8 @@ class FactorWeightFst
   }
 
  private:
-  using ImplToFst<Impl>::GetImpl;
-  using ImplToFst<Impl>::GetMutableImpl;
+  using Base::GetImpl;
+  using Base::GetMutableImpl;
 
   FactorWeightFst &operator=(const FactorWeightFst &) = delete;
 };
