@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -23,12 +23,12 @@
 #include <algorithm>
 #include <initializer_list>
 #include <iostream>
+#include <istream>
+#include <ostream>
 #include <vector>
 
-
 #include <fst/util.h>
 
-
 namespace fst {
 
 // Half-open integral interval [a, b) of signed integers of type T.
