@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -21,12 +21,16 @@
 #define FST_LOG_H_
 
 #include <cassert>
+#include <cstdlib>
 #include <iostream>
 #include <ostream>
 #include <string_view>
 
 #include <fst/flags.h>
 
+class LogMessage;
+class LogMessage;
+
 DECLARE_int32(v);
 
 class LogMessage {
