@@ -297,23 +297,27 @@ struct ErrorLess {
 }  // namespace internal
 
 // Shortest-first queue discipline, templated on the StateId and Weight, is
-// specialized to use the weight's natural order for the comparison function.
-// Requires Weight is idempotent (due to use of NaturalLess).
-template <typename S, typename Weight>
-class NaturalShortestFirstQueue
-    : public ShortestFirstQueue<
-          S, internal::StateWeightCompare<S, NaturalLess<Weight>>> {
+// specialized to use the weight's provided order for the comparison function.
+// See NaturalShortestFirstQueue for the specialization using natural order.
+template <typename S, typename Weight, typename Less>
+class CustomShortestFirstQueue
+    : public ShortestFirstQueue<S, internal::StateWeightCompare<S, Less>> {
  public:
   using StateId = S;
-  using Less = NaturalLess<Weight>;
   using Compare = internal::StateWeightCompare<StateId, Less>;
 
-  explicit NaturalShortestFirstQueue(const std::vector<Weight> &distance)
+  explicit CustomShortestFirstQueue(const std::vector<Weight> &distance)
       : ShortestFirstQueue<StateId, Compare>(Compare(distance, Less())) {}
 
-  ~NaturalShortestFirstQueue() override = default;
+  ~CustomShortestFirstQueue() override = default;
 };
 
+// Shortest-first queue discipline using the weight's natural order.
+// Requires Weight is idempotent (due to use of NaturalLess).
+template <typename S, typename Weight>
+using NaturalShortestFirstQueue =
+    CustomShortestFirstQueue<S, Weight, NaturalLess<Weight>>;
+
 // In a shortest path computation on a lattice-like FST, we may keep many old
 // nonviable paths as a part of the search. Since the search process always
 // expands the lowest cost path next, that lowest cost path may be a very old
