@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,13 +20,18 @@
 #ifndef FST_SCRIPT_COMPILE_IMPL_H_
 #define FST_SCRIPT_COMPILE_IMPL_H_
 
+#include <cstddef>
 #include <iostream>
+#include <istream>
 #include <memory>
+#include <optional>
 #include <sstream>
 #include <string>
 #include <vector>
 
+#include <fst/log.h>
 #include <fst/fst.h>
+#include <fst/properties.h>
 #include <fst/symbol-table.h>
 #include <fst/util.h>
 #include <fst/vector-fst.h>
@@ -47,42 +52,38 @@ class FstCompiler {
   using StateId = typename Arc::StateId;
   using Weight = typename Arc::Weight;
 
-  // WARNING: use of negative labels not recommended as it may cause conflicts.
   // If add_symbols_ is true, then the symbols will be dynamically added to the
   // symbol tables. This is only useful if you set the (i/o)keep flag to attach
   // the final symbol table, or use the accessors. (The input symbol tables are
   // const and therefore not changed.)
-  FstCompiler(std::istream &istrm, const std::string &source,
+  FstCompiler(std::istream &istrm, std::string_view source,
               const SymbolTable *isyms, const SymbolTable *osyms,
               const SymbolTable *ssyms, bool accep, bool ikeep, bool okeep,
-              bool nkeep, bool allow_negative_labels = false) {
+              bool nkeep) {
     std::unique_ptr<SymbolTable> misyms(isyms ? isyms->Copy() : nullptr);
     std::unique_ptr<SymbolTable> mosyms(osyms ? osyms->Copy() : nullptr);
     std::unique_ptr<SymbolTable> mssyms(ssyms ? ssyms->Copy() : nullptr);
     Init(istrm, source, misyms.get(), mosyms.get(), mssyms.get(), accep, ikeep,
-         okeep, nkeep, allow_negative_labels, false);
+         okeep, nkeep, false);
   }
 
-  FstCompiler(std::istream &istrm, const std::string &source,
-              SymbolTable *isyms, SymbolTable *osyms, SymbolTable *ssyms,
-              bool accep, bool ikeep, bool okeep, bool nkeep,
-              bool allow_negative_labels, bool add_symbols) {
+  FstCompiler(std::istream &istrm, std::string_view source, SymbolTable *isyms,
+              SymbolTable *osyms, SymbolTable *ssyms, bool accep, bool ikeep,
+              bool okeep, bool nkeep, bool add_symbols) {
     Init(istrm, source, isyms, osyms, ssyms, accep, ikeep, okeep, nkeep,
-         allow_negative_labels, add_symbols);
+         add_symbols);
   }
 
-  void Init(std::istream &istrm, const std::string &source, SymbolTable *isyms,
+  void Init(std::istream &istrm, std::string_view source, SymbolTable *isyms,
             SymbolTable *osyms, SymbolTable *ssyms, bool accep, bool ikeep,
-            bool okeep, bool nkeep, bool allow_negative_labels,
-            bool add_symbols) {
+            bool okeep, bool nkeep, bool add_symbols) {
     nline_ = 0;
-    source_ = source;
+    source_ = std::string(source);
     isyms_ = isyms;
     osyms_ = osyms;
     ssyms_ = ssyms;
     nstates_ = 0;
     keep_state_numbering_ = nkeep;
-    allow_negative_labels_ = allow_negative_labels;
     add_symbols_ = add_symbols;
     bool start_state_populated = false;
     char line[kLineLen];
@@ -90,7 +91,7 @@ class FstCompiler {
         FST_FLAGS_fst_field_separator + "\n";
     while (istrm.getline(line, kLineLen)) {
       ++nline_;
-      std::vector<std::string_view> col =
+      const std::vector<std::string_view> col =
           StrSplit(line, ByAnyChar(separator), SkipEmpty());
       if (col.empty() || col[0].empty()) continue;
       if (col.size() > 5 || (col.size() > 4 && accep) ||
@@ -106,7 +107,6 @@ class FstCompiler {
         fst_.SetStart(s);
         start_state_populated = true;
       }
-
       Arc arc;
       StateId d = s;
       switch (col.size()) {
@@ -155,11 +155,16 @@ class FstCompiler {
   static constexpr int kLineLen = 8096;
 
   StateId StrToId(std::string_view s, SymbolTable *syms,
-                  std::string_view name, bool allow_negative = false) const {
+                  std::string_view name) const {
     StateId n = 0;
     if (syms) {
-      n = (add_symbols_) ? syms->AddSymbol(s) : syms->Find(s);
-      if (n == kNoSymbol || (!allow_negative && n < 0)) {
+      // n = (add_symbols_) ? syms->AddSymbol(s) : syms->Find(s);
+      if (add_symbols_) {
+        n = syms->AddSymbol(s);
+      } else {
+        n = syms->Find(s);
+      }
+      if (n == kNoSymbol) {
         FSTERROR() << "FstCompiler: Symbol \"" << s
                    << "\" is not mapped to any integer " << name
                    << ", symbol table = " << syms->Name()
@@ -168,7 +173,7 @@ class FstCompiler {
       }
     } else {
       auto maybe_n = ParseInt64(s);
-      if (!maybe_n.has_value() || (!allow_negative && *maybe_n < 0)) {
+      if (!maybe_n.has_value()) {
         FSTERROR() << "FstCompiler: Bad " << name << " integer = \"" << s
                    << "\", source = " << source_ << ", line = " << nline_;
         fst_.SetProperties(kError, kError);
@@ -192,11 +197,11 @@ class FstCompiler {
   }
 
   StateId StrToILabel(std::string_view s) const {
-    return StrToId(s, isyms_, "arc ilabel", allow_negative_labels_);
+    return StrToId(s, isyms_, "arc ilabel");
   }
 
   StateId StrToOLabel(std::string_view s) const {
-    return StrToId(s, osyms_, "arc olabel", allow_negative_labels_);
+    return StrToId(s, osyms_, "arc olabel");
   }
 
   Weight StrToWeight(std::string_view s, bool allow_zero) const {
@@ -221,7 +226,6 @@ class FstCompiler {
   std::unordered_map<StateId, StateId> states_;  // State ID map.
   StateId nstates_;                               // Number of seen states.
   bool keep_state_numbering_;
-  bool allow_negative_labels_;  // Not recommended; may cause conflicts.
   bool add_symbols_;            // Add to symbol tables on-the fly.
 
   FstCompiler(const FstCompiler &) = delete;
