@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -21,6 +21,8 @@
 #include <ostream>
 #include <string>
 
+#include <fst/fst.h>
+#include <fst/symbol-table.h>
 #include <fst/script/draw-impl.h>
 #include <fst/script/fst-class.h>
 
