@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -25,7 +25,9 @@
 #include <utility>
 #include <vector>
 
+#include <fst/mutable-fst.h>
 #include <fst/relabel.h>
+#include <fst/symbol-table.h>
 #include <fst/script/fst-class.h>
 
 namespace fst {
