@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,9 +20,18 @@
 
 #include <cstdint>
 #include <memory>
+#include <tuple>
 #include <vector>
 
+#include <fst/log.h>
+#include <fst/arcfilter.h>
+#include <fst/fst.h>
+#include <fst/mutable-fst.h>
+#include <fst/properties.h>
+#include <fst/queue.h>
 #include <fst/shortest-path.h>
+#include <fst/util.h>
+#include <fst/weight.h>
 #include <fst/script/arcfilter-impl.h>
 #include <fst/script/fst-class.h>
 #include <fst/script/shortest-distance.h>
