@@ -1,4 +1,4 @@
-// Copyright 2005-2020 Google LLC
+// Copyright 2005-2024 Google LLC
 //
 // Licensed under the Apache License, Version 2.0 (the 'License');
 // you may not use this file except in compliance with the License.
@@ -20,6 +20,8 @@
 
 #include <utility>
 
+#include <fst/fst.h>
+#include <fst/mutable-fst.h>
 #include <fst/synchronize.h>
 #include <fst/script/fst-class.h>
 
